# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/acl/acl_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/acl/acl_service.proto\x12\neolymp.acl\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\"M\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x14\n\x0c\x65ntitlements\x18\x04 \x03(\t\"K\n\x14GrantPermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x14\n\x0c\x65ntitlements\x18\x03 \x03(\t\"\x17\n\x15GrantPermissionOutput\"(\n\x15RevokePermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\x18\n\x16RevokePermissionOutput\"*\n\x17\x44\x65scribePermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"F\n\x18\x44\x65scribePermissionOutput\x12*\n\npermission\x18\x01 \x01(\x0b\x32\x16.eolymp.acl.Permission\"\x86\x02\n\x14ListPermissionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.acl.ListPermissionsInput.Filter\x1a\x95\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04role\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"M\n\x15ListPermissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.acl.Permission\"\x1b\n\x19IntrospectPermissionInput\"H\n\x1aIntrospectPermissionOutput\x12*\n\npermission\x18\x01 \x01(\x0b\x32\x16.eolymp.acl.Permission2\x94\x05\n\nAclService\x12}\n\x0fGrantPermission\x12 .eolymp.acl.GrantPermissionInput\x1a!.eolymp.acl.GrantPermissionOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10\x1a\x0e/acl/{user_id}\x12\x80\x01\n\x10RevokePermission\x12!.eolymp.acl.RevokePermissionInput\x1a\".eolymp.acl.RevokePermissionOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10*\x0e/acl/{user_id}\x12\x86\x01\n\x12\x44\x65scribePermission\x12#.eolymp.acl.DescribePermissionInput\x1a$.eolymp.acl.DescribePermissionOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10\x12\x0e/acl/{user_id}\x12s\n\x0fListPermissions\x12 .eolymp.acl.ListPermissionsInput\x1a!.eolymp.acl.ListPermissionsOutput\"\x1b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x06\x12\x04/acl\x12\x85\x01\n\x14IntrospectPermission\x12%.eolymp.acl.IntrospectPermissionInput\x1a&.eolymp.acl.IntrospectPermissionOutput\"\x1e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\t\x12\x07/whoamiB)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.acl_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _ACLSERVICE.methods_by_name['GrantPermission']._options = None
  _ACLSERVICE.methods_by_name['GrantPermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\020\032\016/acl/{user_id}'
  _ACLSERVICE.methods_by_name['RevokePermission']._options = None
  _ACLSERVICE.methods_by_name['RevokePermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\020*\016/acl/{user_id}'
  _ACLSERVICE.methods_by_name['DescribePermission']._options = None
  _ACLSERVICE.methods_by_name['DescribePermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\020\022\016/acl/{user_id}'
  _ACLSERVICE.methods_by_name['ListPermissions']._options = None
  _ACLSERVICE.methods_by_name['ListPermissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\006\022\004/acl'
  _ACLSERVICE.methods_by_name['IntrospectPermission']._options = None
  _ACLSERVICE.methods_by_name['IntrospectPermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\t\022\007/whoami'
  _PERMISSION._serialized_start=146
  _PERMISSION._serialized_end=223
  _GRANTPERMISSIONINPUT._serialized_start=225
  _GRANTPERMISSIONINPUT._serialized_end=300
  _GRANTPERMISSIONOUTPUT._serialized_start=302
  _GRANTPERMISSIONOUTPUT._serialized_end=325
  _REVOKEPERMISSIONINPUT._serialized_start=327
  _REVOKEPERMISSIONINPUT._serialized_end=367
  _REVOKEPERMISSIONOUTPUT._serialized_start=369
  _REVOKEPERMISSIONOUTPUT._serialized_end=393
  _DESCRIBEPERMISSIONINPUT._serialized_start=395
  _DESCRIBEPERMISSIONINPUT._serialized_end=437
  _DESCRIBEPERMISSIONOUTPUT._serialized_start=439
  _DESCRIBEPERMISSIONOUTPUT._serialized_end=509
  _LISTPERMISSIONSINPUT._serialized_start=512
  _LISTPERMISSIONSINPUT._serialized_end=774
  _LISTPERMISSIONSINPUT_FILTER._serialized_start=625
  _LISTPERMISSIONSINPUT_FILTER._serialized_end=774
  _LISTPERMISSIONSOUTPUT._serialized_start=776
  _LISTPERMISSIONSOUTPUT._serialized_end=853
  _INTROSPECTPERMISSIONINPUT._serialized_start=855
  _INTROSPECTPERMISSIONINPUT._serialized_end=882
  _INTROSPECTPERMISSIONOUTPUT._serialized_start=884
  _INTROSPECTPERMISSIONOUTPUT._serialized_end=956
  _ACLSERVICE._serialized_start=959
  _ACLSERVICE._serialized_end=1619
# @@protoc_insertion_point(module_scope)
