# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/executor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.executor import job_pb2 as eolymp_dot_executor_dot_job__pb2
from eolymp.executor import language_pb2 as eolymp_dot_executor_dot_language__pb2
from eolymp.executor import runtime_pb2 as eolymp_dot_executor_dot_runtime__pb2
from eolymp.executor import task_pb2 as eolymp_dot_executor_dot_task__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/executor/executor.proto\x12\x0f\x65olymp.executor\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/executor/job.proto\x1a\x1e\x65olymp/executor/language.proto\x1a\x1d\x65olymp/executor/runtime.proto\x1a\x1a\x65olymp/executor/task.proto\x1a!eolymp/wellknown/expression.proto\"Y\n\x0f\x43reateTaskInput\x12#\n\x04task\x18\x01 \x01(\x0b\x32\x15.eolymp.executor.Task\x12!\n\x03job\x18\x02 \x01(\x0b\x32\x14.eolymp.executor.Job\"\x12\n\x10\x43reateTaskOutput\",\n\x15\x44\x65scribeLanguageInput\x12\x13\n\x0blanguage_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeLanguageOutput\x12+\n\x08language\x18\x01 \x01(\x0b\x32\x19.eolymp.executor.Language\"\xf0\x01\n\x12ListLanguagesInput\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.executor.ListLanguagesInput.Filter\x1a\x9c\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"?\n\x13ListLanguagesOutput\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.executor.Language\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"B\n\x15\x44\x65scribeRuntimeOutput\x12)\n\x07runtime\x18\x01 \x01(\x0b\x32\x18.eolymp.executor.Runtime\"\xcb\x02\n\x10ListRuntimeInput\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.executor.ListRuntimeInput.Filter\x1a\xfb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12,\n\x04lang\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07version\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"<\n\x11ListRuntimeOutput\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.executor.Runtime\"/\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\".\n\x1a\x44\x65scribeCodeTemplateOutput\x12\x10\n\x08template\x18\x01 \x01(\t2\xe7\x07\n\x08\x45xecutor\x12\x63\n\nCreateTask\x12 .eolymp.executor.CreateTaskInput\x1a!.eolymp.executor.CreateTaskOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x12\xb7\x01\n\x10\x44\x65scribeLanguage\x12&.eolymp.executor.DescribeLanguageInput\x1a\'.eolymp.executor.DescribeLanguageOutput\"R\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x1f\x12\x1d/exec/languages/{language_id}\x12\xa0\x01\n\rListLanguages\x12#.eolymp.executor.ListLanguagesInput\x1a$.eolymp.executor.ListLanguagesOutput\"D\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x11\x12\x0f/exec/languages\x12\xb1\x01\n\x0f\x44\x65scribeRuntime\x12%.eolymp.executor.DescribeRuntimeInput\x1a&.eolymp.executor.DescribeRuntimeOutput\"O\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x1c\x12\x1a/exec/runtime/{runtime_id}\x12\x98\x01\n\x0bListRuntime\x12!.eolymp.executor.ListRuntimeInput\x1a\".eolymp.executor.ListRuntimeOutput\"B\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x0f\x12\r/exec/runtime\x12\xc9\x01\n\x14\x44\x65scribeCodeTemplate\x12*.eolymp.executor.DescribeCodeTemplateInput\x1a+.eolymp.executor.DescribeCodeTemplateOutput\"X\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02%\x12#/exec/runtime/{runtime_id}/templateB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.executor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _EXECUTOR.methods_by_name['CreateTask']._options = None
  _EXECUTOR.methods_by_name['CreateTask']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001'
  _EXECUTOR.methods_by_name['DescribeLanguage']._options = None
  _EXECUTOR.methods_by_name['DescribeLanguage']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\037\022\035/exec/languages/{language_id}'
  _EXECUTOR.methods_by_name['ListLanguages']._options = None
  _EXECUTOR.methods_by_name['ListLanguages']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\021\022\017/exec/languages'
  _EXECUTOR.methods_by_name['DescribeRuntime']._options = None
  _EXECUTOR.methods_by_name['DescribeRuntime']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\034\022\032/exec/runtime/{runtime_id}'
  _EXECUTOR.methods_by_name['ListRuntime']._options = None
  _EXECUTOR.methods_by_name['ListRuntime']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\017\022\r/exec/runtime'
  _EXECUTOR.methods_by_name['DescribeCodeTemplate']._options = None
  _EXECUTOR.methods_by_name['DescribeCodeTemplate']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002%\022#/exec/runtime/{runtime_id}/template'
  _CREATETASKINPUT._serialized_start=303
  _CREATETASKINPUT._serialized_end=392
  _CREATETASKOUTPUT._serialized_start=394
  _CREATETASKOUTPUT._serialized_end=412
  _DESCRIBELANGUAGEINPUT._serialized_start=414
  _DESCRIBELANGUAGEINPUT._serialized_end=458
  _DESCRIBELANGUAGEOUTPUT._serialized_start=460
  _DESCRIBELANGUAGEOUTPUT._serialized_end=529
  _LISTLANGUAGESINPUT._serialized_start=532
  _LISTLANGUAGESINPUT._serialized_end=772
  _LISTLANGUAGESINPUT_FILTER._serialized_start=616
  _LISTLANGUAGESINPUT_FILTER._serialized_end=772
  _LISTLANGUAGESOUTPUT._serialized_start=774
  _LISTLANGUAGESOUTPUT._serialized_end=837
  _DESCRIBERUNTIMEINPUT._serialized_start=839
  _DESCRIBERUNTIMEINPUT._serialized_end=881
  _DESCRIBERUNTIMEOUTPUT._serialized_start=883
  _DESCRIBERUNTIMEOUTPUT._serialized_end=949
  _LISTRUNTIMEINPUT._serialized_start=952
  _LISTRUNTIMEINPUT._serialized_end=1283
  _LISTRUNTIMEINPUT_FILTER._serialized_start=1032
  _LISTRUNTIMEINPUT_FILTER._serialized_end=1283
  _LISTRUNTIMEOUTPUT._serialized_start=1285
  _LISTRUNTIMEOUTPUT._serialized_end=1345
  _DESCRIBECODETEMPLATEINPUT._serialized_start=1347
  _DESCRIBECODETEMPLATEINPUT._serialized_end=1394
  _DESCRIBECODETEMPLATEOUTPUT._serialized_start=1396
  _DESCRIBECODETEMPLATEOUTPUT._serialized_end=1442
  _EXECUTOR._serialized_start=1445
  _EXECUTOR._serialized_end=2444
# @@protoc_insertion_point(module_scope)
