# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/asset_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/atlas/asset_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"\x81\x01\n\x0fUploadFileInput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x63hecksum_md5\x18\n \x01(\t\x12\x15\n\rchecksum_sha1\x18\x0b \x01(\t\x12\x17\n\x0f\x63hecksum_sha256\x18\x0c \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\"#\n\x10UploadFileOutput\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\"7\n\x19StartMultipartUploadInput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"/\n\x1aStartMultipartUploadOutput\x12\x11\n\tupload_id\x18\x01 \x01(\t\"G\n\x0fUploadPartInput\x12\x11\n\tupload_id\x18\x01 \x01(\t\x12\x13\n\x0bpart_number\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\" \n\x10UploadPartOutput\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\"\xdd\x01\n\x1c\x43ompleteMultipartUploadInput\x12\x11\n\tupload_id\x18\x01 \x01(\t\x12>\n\x05parts\x18\n \x03(\x0b\x32/.eolymp.atlas.CompleteMultipartUploadInput.Part\x1aj\n\x04Part\x12\x0e\n\x06number\x18\x01 \x01(\r\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x14\n\x0c\x63hecksum_md5\x18\n \x01(\t\x12\x15\n\rchecksum_sha1\x18\x0b \x01(\t\x12\x17\n\x0f\x63hecksum_sha256\x18\x0c \x01(\t\"0\n\x1d\x43ompleteMultipartUploadOutput\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t2\x99\x05\n\x0c\x41ssetService\x12\x87\x01\n\nUploadFile\x12\x1d.eolymp.atlas.UploadFileInput\x1a\x1e.eolymp.atlas.UploadFileOutput\":\x82\xe3\n\x14\x8a\xe3\n\x10\x61tlas:file:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\"\x0b/data/files\x12\xa7\x01\n\x14StartMultipartUpload\x12\'.eolymp.atlas.StartMultipartUploadInput\x1a(.eolymp.atlas.StartMultipartUploadOutput\"<\x82\xe3\n\x14\x8a\xe3\n\x10\x61tlas:file:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0f\x1a\r/data/uploads\x12\x95\x01\n\nUploadPart\x12\x1d.eolymp.atlas.UploadPartInput\x1a\x1e.eolymp.atlas.UploadPartOutput\"H\x82\xe3\n\x14\x8a\xe3\n\x10\x61tlas:file:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1b\"\x19/data/uploads/{upload_id}\x12\xbc\x01\n\x17\x43ompleteMultipartUpload\x12*.eolymp.atlas.CompleteMultipartUploadInput\x1a+.eolymp.atlas.CompleteMultipartUploadOutput\"H\x82\xe3\n\x14\x8a\xe3\n\x10\x61tlas:file:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1b\x1a\x19/data/uploads/{upload_id}B-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.asset_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _ASSETSERVICE.methods_by_name['UploadFile']._options = None
  _ASSETSERVICE.methods_by_name['UploadFile']._serialized_options = b'\202\343\n\024\212\343\n\020atlas:file:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\r\"\013/data/files'
  _ASSETSERVICE.methods_by_name['StartMultipartUpload']._options = None
  _ASSETSERVICE.methods_by_name['StartMultipartUpload']._serialized_options = b'\202\343\n\024\212\343\n\020atlas:file:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\017\032\r/data/uploads'
  _ASSETSERVICE.methods_by_name['UploadPart']._options = None
  _ASSETSERVICE.methods_by_name['UploadPart']._serialized_options = b'\202\343\n\024\212\343\n\020atlas:file:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\033\"\031/data/uploads/{upload_id}'
  _ASSETSERVICE.methods_by_name['CompleteMultipartUpload']._options = None
  _ASSETSERVICE.methods_by_name['CompleteMultipartUpload']._serialized_options = b'\202\343\n\024\212\343\n\020atlas:file:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\033\032\031/data/uploads/{upload_id}'
  _UPLOADFILEINPUT._serialized_start=150
  _UPLOADFILEINPUT._serialized_end=279
  _UPLOADFILEOUTPUT._serialized_start=281
  _UPLOADFILEOUTPUT._serialized_end=316
  _STARTMULTIPARTUPLOADINPUT._serialized_start=318
  _STARTMULTIPARTUPLOADINPUT._serialized_end=373
  _STARTMULTIPARTUPLOADOUTPUT._serialized_start=375
  _STARTMULTIPARTUPLOADOUTPUT._serialized_end=422
  _UPLOADPARTINPUT._serialized_start=424
  _UPLOADPARTINPUT._serialized_end=495
  _UPLOADPARTOUTPUT._serialized_start=497
  _UPLOADPARTOUTPUT._serialized_end=529
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_start=532
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_end=753
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_start=647
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_end=753
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_start=755
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_end=803
  _ASSETSERVICE._serialized_start=806
  _ASSETSERVICE._serialized_end=1471
# @@protoc_insertion_point(module_scope)
