# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/membership_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)eolymp/community/membership_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/community/attribute.proto\x1a\x1d\x65olymp/community/member.proto\"\x19\n\x17\x44\x65scribeMembershipInput\"D\n\x18\x44\x65scribeMembershipOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"N\n\x15UpdateMembershipInput\x12\x35\n\nattributes\x18\x01 \x03(\x0b\x32!.eolymp.community.Attribute.Value\"\x18\n\x16UpdateMembershipOutput2\xe0\x02\n\x11MembershipService\x12\x92\x01\n\x12\x44\x65scribeMembership\x12).eolymp.community.DescribeMembershipInput\x1a*.eolymp.community.DescribeMembershipOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x10\x12\x0e/members/_self\x12\xb5\x01\n\x10UpdateMembership\x12\'.eolymp.community.UpdateMembershipInput\x1a(.eolymp.community.UpdateMembershipOutput\"N\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1b\"\x19/members/_self/attributesB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.membership_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _MEMBERSHIPSERVICE.methods_by_name['DescribeMembership']._options = None
  _MEMBERSHIPSERVICE.methods_by_name['DescribeMembership']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\020\022\016/members/_self'
  _MEMBERSHIPSERVICE.methods_by_name['UpdateMembership']._options = None
  _MEMBERSHIPSERVICE.methods_by_name['UpdateMembership']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\033\"\031/members/_self/attributes'
  _DESCRIBEMEMBERSHIPINPUT._serialized_start=227
  _DESCRIBEMEMBERSHIPINPUT._serialized_end=252
  _DESCRIBEMEMBERSHIPOUTPUT._serialized_start=254
  _DESCRIBEMEMBERSHIPOUTPUT._serialized_end=322
  _UPDATEMEMBERSHIPINPUT._serialized_start=324
  _UPDATEMEMBERSHIPINPUT._serialized_end=402
  _UPDATEMEMBERSHIPOUTPUT._serialized_start=404
  _UPDATEMEMBERSHIPOUTPUT._serialized_end=428
  _MEMBERSHIPSERVICE._serialized_start=431
  _MEMBERSHIPSERVICE._serialized_end=783
# @@protoc_insertion_point(module_scope)
