# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/report.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import usage_pb2 as eolymp_dot_executor_dot_usage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/executor/report.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/usage.proto\"\xf6\x0c\n\x06Report\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x12\n\nagent_name\x18n \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12,\n\x05state\x18\n \x01(\x0e\x32\x1d.eolymp.executor.Report.State\x12-\n\x06\x61\x63tors\x18\x32 \x03(\x0b\x32\x1d.eolymp.executor.Report.Actor\x12)\n\x04runs\x18( \x03(\x0b\x32\x1b.eolymp.executor.Report.Run\x12\r\n\x05\x65rror\x18\x14 \x01(\t\x1a\xa9\x01\n\x05\x41\x63tor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\t\x12\x37\n\nerror_code\x18\n \x01(\x0e\x32#.eolymp.executor.Report.Actor.Error\x12\x15\n\rerror_message\x18\x0b \x01(\t\"/\n\x05\x45rror\x12\x08\n\x04NONE\x10\x00\x12\x0e\n\nINIT_ERROR\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\x1a\x8a\x01\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12,\n\x05state\x18\x02 \x01(\x0e\x32\x1d.eolymp.executor.Report.State\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12+\n\x05steps\x18\n \x03(\x0b\x32\x1c.eolymp.executor.Report.Step\x1a\xe9\x07\n\x04Step\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x07outcome\x18\x02 \x01(\x0e\x32$.eolymp.executor.Report.Step.Outcome\x12\x37\n\x07\x65xecute\x18\x0c \x01(\x0b\x32$.eolymp.executor.Report.Step.ExecuteH\x00\x12\x35\n\x06upload\x18\r \x01(\x0b\x32#.eolymp.executor.Report.Step.UploadH\x00\x12\x33\n\x05group\x18\x0e \x01(\x0b\x32\".eolymp.executor.Report.Step.GroupH\x00\x1a\xad\x04\n\x07\x45xecute\x12\r\n\x05\x61\x63tor\x18\x01 \x01(\t\x12>\n\x0b\x65xit_status\x18\x02 \x01(\x0e\x32).eolymp.executor.Report.Step.Execute.Exit\x12@\n\x06values\x18\x03 \x03(\x0b\x32\x30.eolymp.executor.Report.Step.Execute.ValuesEntry\x12\x17\n\x0fwall_time_usage\x18\x33 \x01(\r\x12\x17\n\x0fwall_time_limit\x18= \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x34 \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18> \x01(\r\x12\x14\n\x0cmemory_usage\x18\x35 \x01(\x04\x12\x14\n\x0cmemory_limit\x18? \x01(\x04\x12\x11\n\texit_code\x18\x46 \x01(\r\x12\x0e\n\x06signal\x18G \x01(\r\x12\x36\n\x0eresource_usage\x18P \x01(\x0b\x32\x1e.eolymp.executor.ResourceUsage\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x04\x45xit\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x0b\n\x07TIMEOUT\x10\x02\x12\x11\n\rCPU_EXHAUSTED\x10\x03\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x04\x12\x11\n\rRUNTIME_ERROR\x10\x05\x12\x0b\n\x07SKIPPED\x10\x06\x1a\x45\n\x06Upload\x12\x13\n\x0btarget_name\x18\x01 \x01(\t\x12\x12\n\ntarget_ern\x18\x02 \x01(\t\x12\x12\n\ntarget_url\x18\x03 \x01(\t\x1a@\n\x05Group\x12\x37\n\tprocesses\x18\x01 \x03(\x0b\x32$.eolymp.executor.Report.Step.Execute\"4\n\x07Outcome\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x43OMPLETE\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x42\x08\n\x06output\"h\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07\x42LOCKED\x10\x05\x12\x0b\n\x07SKIPPED\x10\x06\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.report_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _REPORT_STEP_EXECUTE_VALUESENTRY._options = None
  _REPORT_STEP_EXECUTE_VALUESENTRY._serialized_options = b'8\001'
  _REPORT._serialized_start=79
  _REPORT._serialized_end=1733
  _REPORT_ACTOR._serialized_start=313
  _REPORT_ACTOR._serialized_end=482
  _REPORT_ACTOR_ERROR._serialized_start=435
  _REPORT_ACTOR_ERROR._serialized_end=482
  _REPORT_RUN._serialized_start=485
  _REPORT_RUN._serialized_end=623
  _REPORT_STEP._serialized_start=626
  _REPORT_STEP._serialized_end=1627
  _REPORT_STEP_EXECUTE._serialized_start=869
  _REPORT_STEP_EXECUTE._serialized_end=1426
  _REPORT_STEP_EXECUTE_VALUESENTRY._serialized_start=1258
  _REPORT_STEP_EXECUTE_VALUESENTRY._serialized_end=1303
  _REPORT_STEP_EXECUTE_EXIT._serialized_start=1305
  _REPORT_STEP_EXECUTE_EXIT._serialized_end=1426
  _REPORT_STEP_UPLOAD._serialized_start=1428
  _REPORT_STEP_UPLOAD._serialized_end=1497
  _REPORT_STEP_GROUP._serialized_start=1499
  _REPORT_STEP_GROUP._serialized_end=1563
  _REPORT_STEP_OUTCOME._serialized_start=1565
  _REPORT_STEP_OUTCOME._serialized_end=1617
  _REPORT_STATE._serialized_start=1629
  _REPORT_STATE._serialized_end=1733
# @@protoc_insertion_point(module_scope)
